Function framebuffer_printer::print_ascii_character
source · pub fn print_ascii_character<P: Pixel>(
framebuffer: &mut Framebuffer<P>,
character: u8,
fg_pixel: P,
bg_pixel: P,
coordinate: Coord,
column: usize,
line: usize
)Expand description
Prints a character to the framebuffer at position (line, column) of all characters in the text area.
Arguments
framebuffer: the framebuffer to display in.character: the ASCII code of the character to display.fg_pixel: the value of every pixel in the character.bg_color: the value of every pixel in the background.coordinate: the left top coordinate of the text block relative to the origin(top-left point) of the framebuffer.column,line: the location of the character in the text block as symbols.